@@ -26,13 +26,13 @@ See L<UI::Various::language::en> for more details.
 
 #########################################################################
 
-use v5.14.0;
+use v5.14;
 use strictures;
 no indirect 'fatal';
 no multidimensional;
 use warnings 'once';
 
-our $VERSION = '0.07';
+our $VERSION = '0.09';
 
 #########################################################################
 
