@@ -68,13 +68,13 @@ script C<L<update-language.pl>> with the string as sole parameter.
 
 #########################################################################
 
-use v5.14.0;
+use v5.14;
 use strictures;
 no indirect 'fatal';
 no multidimensional;
 use warnings 'once';
 
-our $VERSION = '0.07';
+our $VERSION = '0.09';
 
 #########################################################################
 
